##  Using SAP Suggestions for Strategic Planning and Optimization
Use SAP suggestions to enhance the relevance of existing SAP products. In a report, select a suggestion that highlights an existing fact sheet from a business capability where you see an optimization opportunity. Preview data in the side panel to identify existing corresponding applications or agents.
Navigate to the corresponding fact sheet you want to use for the target business capability. You can either link the business capability directly to your fact sheet or create a transformation process for it.
Follow these best practices:
  * Add potential AI agents to your inventory early. This allows you to start assessing risks and potential, which is a prerequisite for approving AI agents.
  * Link activated suggestions to processes and organizations. This helps you better assess potential and adoption.
  * Create initiatives that support the introduction or expansion of SAP suggestions.
  * Use transformations to plan the next steps for optimizing your landscape.


YesNo
Send
